"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegisterSubcommandsHooks = void 0;
const framework_1 = require("@sapphire/framework");
const v10_1 = require("discord-api-types/v10");
const functions_1 = require("./functions");
const index_1 = require("../../index");
/**
 * **Hooks**
 *
 * Methods needed to register commands as subcommands and commands in subcommand groups.
 *
 * @since 1.0.0
 */
exports.RegisterSubcommandsHooks = {
    subcommands: (piece, context) => {
        const subcommands = functions_1.subCommandsRegistry.get(piece.name);
        if (!subcommands) {
            framework_1.container.logger.error(`[Subcommands-Plugin]: An attempt was made to obtain the subcommands for the parent command ${piece.name} but no command was registered for it.`);
            return;
        }
        for (const { slashCommand, commandPiece } of subcommands.values()) {
            context.options.push(slashCommand);
            const subcommand = {
                name: slashCommand.name,
                type: 'method',
                chatInputRun: commandPiece.chatInputRun
                    ? async (i, c) => {
                        const preconditions = new framework_1.PreconditionContainerArray(commandPiece.options.preconditions);
                        const result = await preconditions.chatInputRun(i, piece);
                        if (result.isErr())
                            return piece.container.client.emit(index_1.SubcommandsAdvancedEvents.ChatInputSubcommandDenied, result.err().unwrapOr('Unknown error'), {
                                command: piece,
                                interaction: i,
                                subcommand: subcommand
                            });
                        return commandPiece.chatInputRun(i, c);
                    }
                    : undefined
                // Support for message commands coming soon
                /* 				messageRun: commandPiece.chatInputRun
                    ? async (m, a, c) => {
                            const preconditions = new PreconditionContainerArray(commandPiece.options.preconditions);
                            const result = await preconditions.messageRun(m, piece, c);
                            if (!result.success)
                                return piece.container.client.emit(AdvancedSubcommandsEvents.MessageSubcommandDenied, result.error, {
                                    command: piece,
                                    message: m,
                                    subcommand: subcommand as any
                                });

                            return commandPiece.messageRun!(m, a, c);
                      }
                    : undefined */
            };
            piece.parsedSubcommandMappings.push(subcommand);
        }
    },
    groups: (piece, context) => {
        const subcommandsGroups = functions_1.subCommandsGroupRegistry.get(piece.name);
        if (!subcommandsGroups) {
            framework_1.container.logger.error(`[Subcommands-Group-Plugin]: An attempt was made to obtain the subcommand groups for the parent command ${piece.name} but no command was registered for it.`);
            return;
        }
        for (const [name, commands] of subcommandsGroups) {
            for (const { slashCommand, commandPiece } of [...commands.values()]) {
                const groupMapping = piece.parsedSubcommandMappings.find(({ name: x, type }) => x === name && type === 'group');
                const subcommand = {
                    name: slashCommand.name,
                    type: 'method',
                    chatInputRun: commandPiece.chatInputRun
                        ? async (i, c) => {
                            const preconditions = new framework_1.PreconditionContainerArray(commandPiece.options.preconditions);
                            const result = await preconditions.chatInputRun(i, piece);
                            if (result.isErr())
                                return piece.container.client.emit(index_1.SubcommandsAdvancedEvents.ChatInputSubcommandDenied, result.err().unwrapOr('Unknown error'), {
                                    command: piece,
                                    interaction: i,
                                    subcommand: subcommand
                                });
                            return commandPiece.chatInputRun(i, c);
                        }
                        : undefined
                    // Support for message commands coming soon
                    /* 					messageRun: commandPiece.chatInputRun
                        ? async (m, a, c) => {
                                const preconditions = new PreconditionContainerArray(commandPiece.options.preconditions);
                                const result = await preconditions.messageRun(m, piece, c);
                                if (!result.success)
                                    return piece.container.client.emit(AdvancedSubcommandsEvents.MessageSubcommandDenied, result.error, {
                                        command: piece,
                                        message: m,
                                        subcommand: subcommand as any
                                    });

                                return commandPiece.messageRun!(m, a, c);
                          }
                        : undefined */
                };
                if (groupMapping)
                    groupMapping.entries.push(subcommand);
                else {
                    piece.parsedSubcommandMappings.push({
                        name,
                        type: 'group',
                        entries: [subcommand]
                    });
                }
            }
            for (const option of context.options) {
                const data = option.toJSON();
                if (data.name === name && data.type === v10_1.ApplicationCommandOptionType.SubcommandGroup) {
                    option.options?.push(...[...commands.values()].map(({ slashCommand }) => slashCommand));
                }
            }
        }
    }
};
//# sourceMappingURL=const.js.map