import { Command, container } from '@sapphire/framework';
import { Collection } from 'discord.js';
import { SlashCommandSubcommandBuilder } from '@discordjs/builders';
import type { SubcommandMappingCollection } from './types';
/**
 * **Registry**
 *
 * Subcommands registry.
 *
 * @since 1.0.0
 */
export declare const subCommandsRegistry: Collection<string, Collection<string, SubcommandMappingCollection>>;
/**
 * **Registry**
 *
 * Subcommands group registry.
 *
 * @since 1.0.0
 */
export declare const subCommandsGroupRegistry: Collection<string, Collection<string, Collection<string, SubcommandMappingCollection>>>;
/**
 * **Subcommands compare**
 *
 * Compare two subcommand builders.
 *
 * @param c1 SubcommandBuilder 1
 * @param c2 SubcommandBuilder 2
 * @returns boolean
 * @since 1.0.0
 */
export declare const isCommandOptionsUpdated: (c1: SlashCommandSubcommandBuilder, c2: SlashCommandSubcommandBuilder) => boolean;
/**
 * Parse slash subcommand option
 * @param subcommand subcommand json or subcommand builder class.
 * @returns subcommand builder
 *
 * @since 2.0.0
 */
export declare const parseSlashSubcommand: (subcommand: SlashCommandSubcommandBuilder | ((subcommandGroup: SlashCommandSubcommandBuilder, Container: typeof container) => SlashCommandSubcommandBuilder)) => SlashCommandSubcommandBuilder;
/**
 * **Register subcommands in subcommands registry**
 *
 * Method that parses and registers subcommands in parent commands.
 *
 * @param piece Class of the command to be used as a subcommand of the parent command.
 * @param parentCommandName Name of the parent command.
 * @param subcommand Builder of the subcommand to be analyzed in the subcommand register.
 * @returns	Command class
 * @since 1.0.0
 */
export declare const analizeSubCommandParsed: (piece: Command, parentCommandName: string, subcommand: SlashCommandSubcommandBuilder | ((subcommandGroup: SlashCommandSubcommandBuilder, Container: typeof container) => SlashCommandSubcommandBuilder)) => Command<import("@sapphire/framework").Args, import("@sapphire/framework").CommandOptions>;
/**
 * **Register subcommands in subcommands group registry**
 *
 * Method that parses and registers subcommands in parent commands.
 *
 * @param piece Class of the command to be used as a subcommand of the parent command.
 * @param parentCommandName Name of the parent command.
 * @param groupName Name of the subcommand group.
 * @param subcommand Builder of the subcommand to be analyzed in the subcommand register.
 * @returns	Command class
 * @since 1.0.0
 */
export declare const analizeSubcommandGroupParsed: (piece: Command, parentCommandName: string, groupName: string, subcommand: SlashCommandSubcommandBuilder | ((subcommandGroup: SlashCommandSubcommandBuilder, Container: typeof container) => SlashCommandSubcommandBuilder)) => Command<import("@sapphire/framework").Args, import("@sapphire/framework").CommandOptions>;
//# sourceMappingURL=functions.d.ts.map